@@ -7,6 +7,27 @@ from xklb import db, utils
 from xklb.utils import log
 
 
+def group_by_folder(args, media):
+    d = {}
+    for m in media:
+        p = m["path"].split("/")
+        while len(p) >= 3:
+            p.pop()
+            parent = "/".join(p) + "/"
+
+            if d.get(parent):
+                d[parent]["size"] += m["size"]
+                d[parent]["count"] += 1
+            else:
+                d[parent] = dict(size=m["size"], count=1)
+
+    for path, pdict in list(d.items()):
+        if pdict["count"] < args.lower or pdict["count"] > args.upper:
+            d.pop(path)
+
+    return [{**v, "path": k} for k, v in d.items()]
+
+
 def get_table(args) -> List[dict]:
     columns = args.db["media"].columns_dict
 
@@ -23,34 +44,16 @@ def get_table(args) -> List[dict]:
         )
     )
 
-    d = {}
-    for m in media:
-        p = m["path"].split("/")
-        while len(p) >= 3:
-            p.pop()
-            parent = "/".join(p) + "/"
-
-            if d.get(parent):
-                d[parent]["size"] += m["size"]
-                d[parent]["count"] += 1
-            else:
-                d[parent] = dict(size=m["size"], count=1)
-
-    for path, pdict in list(d.items()):
-        if pdict["count"] < args.lower or pdict["count"] > args.upper:
-            d.pop(path)
-
-    d = [{**v, "path": k} for k, v in d.items()]
-
-    return sorted(d, key=lambda x: x["size"])
+    folders = group_by_folder(args, media)
+    return sorted(folders, key=lambda x: x["size"])
 
 
 def parse_args() -> argparse.Namespace:
     parser = argparse.ArgumentParser()
     parser.add_argument("database")
-    parser.add_argument("--limit", "-L", "-l", "-queue", "--queue")
-    parser.add_argument("--lower", default=35, type=int)
-    parser.add_argument("--upper", default=3500, type=int)
+    parser.add_argument("--limit", "-L", "-l", "-queue", "--queue", default="4000")
+    parser.add_argument("--lower", default=4, type=int, help="Number of files per folder lower limit")
+    parser.add_argument("--upper", default=4000, type=int, help="Number of files per folder upper limit")
     parser.add_argument("--verbose", "-v", action="count", default=0)
     args = parser.parse_args()
     args.db = db.connect(args)
