@@ -5,9 +5,7 @@ from shutil import which
 from timeit import default_timer as timer
 from typing import Dict, List, Optional
 
-from joblib import Parallel, delayed
-
-from xklb import av, books, consts, db, utils
+from xklb import av, books, consts, db, player, utils
 from xklb.consts import SC, DBType
 from xklb.player import mark_media_deleted
 from xklb.utils import log
@@ -70,6 +68,8 @@ def extract_metadata(mp_args, f) -> Optional[Dict[str, int]]:
 
 
 def extract_chunk(args, chunk_paths) -> None:
+    from joblib import Parallel, delayed
+
     n_jobs = -1
     if args.profile in (DBType.text, DBType.image, DBType.filesystem):
         n_jobs = consts.CPU_COUNT
@@ -155,20 +155,23 @@ def _add_folder(args, folder_path: Path) -> None:
 
 def scan_path(args, path_str: str) -> int:
     path = Path(path_str).resolve()
+
     if not path.exists():
         print(f"[{path}] Path does not exist")
-        if not args.force:
-            return 0
+        if args.force:
+            player.delete_playlists(args, [path_str])
+        return 0
+
     print(f"[{path}] Building file list...")
-
     new_files = find_new_files(args, path)
-
     if new_files:
         print(f"[{path}] Adding {len(new_files)} new media")
         log.debug(new_files)
 
         if args.profile in (DBType.text):
             batch_count = consts.CPU_COUNT
+        elif args.profile in (DBType.image):
+            batch_count = consts.SQLITE_PARAM_LIMIT // 20
         else:
             batch_count = consts.SQLITE_PARAM_LIMIT // 100
         chunks_count = math.ceil(len(new_files) / batch_count)
