@@ -388,8 +388,12 @@ def update_playlists(args, playlists):
 
 def save_tube_entry(args, m, info: Optional[dict] = None, error=None, URE=False) -> None:
     webpath = m["path"]
-    error = None if not error else error.replace(m.get("id", ""), "").replace(" :", ":")
-    if not info:  # not downloaded
+
+    v_id = m.get("id")
+    if v_id:
+        error = None if not error else error.replace(v_id, "").replace(" :", ":")
+
+    if not info:  # not downloaded or already downloaded
         entry = {
             "path": webpath,
             "time_downloaded": 0,
@@ -438,7 +442,7 @@ def yt(args, m) -> None:
     if not m["path"].startswith("http"):
         return
 
-    ydl_log = {"warning": [], "error": []}
+    ydl_log = {"warning": [], "error": [], "info": []}
 
     class BadToTheBoneLogger:
         def debug(self, msg):
@@ -448,7 +452,7 @@ def yt(args, m) -> None:
                 self.info(msg)
 
         def info(self, msg):
-            pass
+            ydl_log["info"].append(msg)
 
         def warning(self, msg):
             ydl_log["warning"].append(msg)
@@ -456,11 +460,15 @@ def yt(args, m) -> None:
         def error(self, msg):
             ydl_log["error"].append(msg)
 
+    ignoreerrors = False
+    if m.get("time_modified") and m.get("time_modified") > 0:
+        ignoreerrors = True
+
     out_dir = lambda p: str(Path(args.prefix, m["category"] or "%(extractor_key,extractor)s", p))
     ydl_opts = tube_opts(
         args,
         func_opts={
-            "ignoreerrors": False,
+            "ignoreerrors": ignoreerrors,
             "subtitleslangs": ["en.*", "EN.*"],
             "extractor_args": {"youtube": {"skip": ["authcheck"]}},
             "logger": BadToTheBoneLogger(),
@@ -517,30 +525,33 @@ def yt(args, m) -> None:
             info = ydl.extract_info(m["path"], download=True)
         except yt_dlp.DownloadError as e:
             error = consts.REGEX_ANSI_ESCAPE.sub("", str(e))
-            log.warning("[%s]: yt-dlp %s", m["path"], error)
-            save_tube_entry(args, m, error=error)
-            return
-        if info is None:
-            log.warning("[%s]: yt-dlp returned no info", m["path"])
-            save_tube_entry(args, m, error="yt-dlp returned no info")
-            return
+            ydl_log["error"].append(error)
+            info = None
+            log.debug("[%s]: yt-dlp %s", m["path"], error)
+            # save_tube_entry(args, m, error=error)
+            # return
 
-        if args.profile == DBType.audio:
-            info["local_path"] = ydl.prepare_filename({**info, "ext": args.ext})
+        if info is None:
+            log.debug("[%s]: yt-dlp returned no info", m["path"])
         else:
-            info["local_path"] = ydl.prepare_filename(info)
+            if args.profile == DBType.audio:
+                info["local_path"] = ydl.prepare_filename({**info, "ext": args.ext})
+            else:
+                info["local_path"] = ydl.prepare_filename(info)
 
         ydl_errors = ydl_log["error"] + ydl_log["warning"]
-        ydl_errors = "\n".join([s for s in ydl_errors if not yt_meaningless_errors.match(s)])
+        ydl_errors = "\n".join([l for l in ydl_errors if not yt_meaningless_errors.match(l)])
+        ydl_full_log = ydl_log["error"] + ydl_log["warning"] + ydl_log["info"]
 
-        if not ydl_log["error"]:
+        if not ydl_log["error"] and info:
             log.debug("[%s]: No news is good news", m["path"])
             save_tube_entry(args, m, info)
-        elif yt_recoverable_errors.match(ydl_errors):
-            log.info("[%s]: Recoverable error matched. %s", m["path"], ydl_errors)
+        elif any([yt_recoverable_errors.match(l) for l in ydl_full_log]):
+            log.info("[%s]: Recoverable error matched (will try again later). %s", m["path"], ydl_errors)
             save_tube_entry(args, m, info, error=ydl_errors)
-        elif yt_unrecoverable_errors.match(ydl_errors):
-            log.info("[%s]: Unrecoverable error matched. %s", m["path"], ydl_errors)
+        elif any([yt_unrecoverable_errors.match(l) for l in ydl_full_log]):
+            matched_error = [m.string for m in utils.conform([yt_unrecoverable_errors.match(l) for l in ydl_full_log])]
+            log.info("[%s]: Unrecoverable error matched. %s", m["path"], ydl_errors or utils.combine(matched_error))
             save_tube_entry(args, m, info, error=ydl_errors, URE=True)
         else:
             log.warning("[%s]: Unknown error. %s", m["path"], ydl_errors)
